summaryrefslogtreecommitdiffstats
path: root/konversation/src/linkaddressbook/kimiface.h
diff options
context:
space:
mode:
Diffstat (limited to 'konversation/src/linkaddressbook/kimiface.h')
-rw-r--r--konversation/src/linkaddressbook/kimiface.h48
1 files changed, 24 insertions, 24 deletions
diff --git a/konversation/src/linkaddressbook/kimiface.h b/konversation/src/linkaddressbook/kimiface.h
index 990f980..99daf2c 100644
--- a/konversation/src/linkaddressbook/kimiface.h
+++ b/konversation/src/linkaddressbook/kimiface.h
@@ -21,9 +21,9 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
#ifndef KIMIFACE_H
#define KIMIFACE_H
-#include <qpixmap.h>
+#include <tqpixmap.h>
#include <dcopobject.h>
-#include <qstringlist.h>
+#include <tqstringlist.h>
#include <kurl.h>
/**
@@ -43,25 +43,25 @@ class KIMIface : virtual public DCOPObject
* address book.
* @return a list of KABC uids.
*/
- virtual QStringList allContacts() = 0;
+ virtual TQStringList allContacts() = 0;
/**
* Obtain a list of KDE address book entries who are
* currently reachable.
* @return a list of KABC uids who can receive a message, even if online.
*/
- virtual QStringList reachableContacts() = 0;
+ virtual TQStringList reachableContacts() = 0;
/**
* Obtain a list of KDE address book entries who are
* currently online.
* @return a list of KABC uids who are online with unspecified presence.
*/
- virtual QStringList onlineContacts() = 0;
+ virtual TQStringList onlineContacts() = 0;
/**
* Obtain a list of KDE address book entries who may
* receive file transfers.
* @return a list of KABC uids capable of file transfer.
*/
- virtual QStringList fileTransferContacts() = 0;
+ virtual TQStringList fileTransferContacts() = 0;
// individual
/**
@@ -69,38 +69,38 @@ class KIMIface : virtual public DCOPObject
* @param uid the KABC uid you are interested in.
* @return whether one of the chat programs KIMProxy talks to knows of this KABC uid.
*/
- virtual bool isPresent( const QString & uid ) = 0;
+ virtual bool isPresent( const TQString & uid ) = 0;
/**
* Obtain the IM app's idea of the contact's display name
* Useful if KABC lookups may be too slow
* @param uid KABC uid.
* @return The corresponding display name.
*/
- virtual QString displayName( const QString & uid ) = 0;
+ virtual TQString displayName( const TQString & uid ) = 0;
/**
* Obtain the IM presence as a i18ned string for the specified addressee
* @param uid the KABC uid you want the presence for.
* @return the i18ned string describing presence.
*/
- virtual QString presenceString( const QString & uid ) = 0;
+ virtual TQString presenceString( const TQString & uid ) = 0;
/**
* Obtain the IM presence as a number (see KIMIface) for the specified addressee
* @param uid the KABC uid you want the presence for.
* @return a numeric representation of presence - currently one of 0 (Unknown), 1 (Offline), 2 (Connecting), 3 (Away), 4 (Online)
*/
- virtual int presenceStatus( const QString & uid ) = 0;
+ virtual int presenceStatus( const TQString & uid ) = 0;
/**
* Indicate if a given uid can receive files
* @param uid the KABC uid you are interested in.
* @return Whether the specified addressee can receive files.
*/
- virtual bool canReceiveFiles( const QString & uid ) = 0;
+ virtual bool canReceiveFiles( const TQString & uid ) = 0;
/**
* Some media are unidirectional (eg, sending SMS via a web interface).
* @param uid the KABC uid you are interested in.
* @return Whether the specified addressee can respond.
*/
- virtual bool canRespond( const QString & uid ) = 0;
+ virtual bool canRespond( const TQString & uid ) = 0;
/**
* Get the KABC uid corresponding to the supplied IM address
* Protocols should be
@@ -108,26 +108,26 @@ class KIMIface : virtual public DCOPObject
* @param protocol the protocol, eg one of "AIMProtocol", "MSNProtocol", "ICQProtocol",
* @return a KABC uid or null if none found/
*/
- virtual QString locate( const QString & contactId, const QString & protocol ) = 0;
+ virtual TQString locate( const TQString & contactId, const TQString & protocol ) = 0;
// metadata
/**
* Obtain the icon representing IM presence for the specified addressee
* @param uid the KABC uid you want the presence for.
* @return a pixmap representing the uid's presence.
*/
- virtual QPixmap icon( const QString & uid ) = 0;
+ virtual TQPixmap icon( const TQString & uid ) = 0;
/**
* Get the supplied addressee's current context (home, work, or any).
* @param uid the KABC uid you want the context for.
* @return A QString describing the context, or null if not supported.
*/
- virtual QString context( const QString & uid ) = 0;
+ virtual TQString context( const TQString & uid ) = 0;
// App capabilities
/**
* Discover what protocols the application supports
* @return the set of protocols that the application supports
*/
- virtual QStringList protocols() = 0;
+ virtual TQStringList protocols() = 0;
// ACTORS
/**
@@ -137,18 +137,18 @@ class KIMIface : virtual public DCOPObject
* @param uid the KABC uid you want to chat with.
* @param message the message to send them.
*/
- virtual void messageContact( const QString &uid, const QString& message ) = 0;
+ virtual void messageContact( const TQString &uid, const TQString& message ) = 0;
/**
* Open a chat to a contact, and optionally set some initial text
*/
- virtual void messageNewContact( const QString &contactId, const QString &protocol ) = 0;
+ virtual void messageNewContact( const TQString &contactId, const TQString &protocol ) = 0;
/**
* Start a chat session with the specified addressee
* @param uid the KABC uid you want to chat with.
*/
- virtual void chatWithContact( const QString &uid ) = 0;
+ virtual void chatWithContact( const TQString &uid ) = 0;
/**
* Send the file to the contact
@@ -157,8 +157,8 @@ class KIMIface : virtual public DCOPObject
* @param altFileName an alternate filename describing the file
* @param fileSize file size in bytes
*/
- virtual void sendFile(const QString &uid, const KURL &sourceURL,
- const QString &altFileName = QString(), uint fileSize = 0) = 0;
+ virtual void sendFile(const TQString &uid, const KURL &sourceURL,
+ const TQString &altFileName = TQString(), uint fileSize = 0) = 0;
// MUTATORS
// Contact list
@@ -168,7 +168,7 @@ class KIMIface : virtual public DCOPObject
* @param protocol the protocol, eg one of "AIMProtocol", "MSNProtocol", "ICQProtocol", ...
* @return whether the add succeeded. False may signal already present, protocol not supported, or add operation not supported.
*/
- virtual bool addContact( const QString &contactId, const QString &protocol ) = 0;
+ virtual bool addContact( const TQString &contactId, const TQString &protocol ) = 0;
// SIGNALS
k_dcop_signals:
/**
@@ -177,7 +177,7 @@ class KIMIface : virtual public DCOPObject
* @param appId the dcop application id of the program the signal originates from.
* @param presence the new numeric presence @ref presenceStatus
*/
- void contactPresenceChanged( QString uid, QCString appId, int presence );
+ void contactPresenceChanged( TQString uid, TQCString appId, int presence );
};
#endif
@@ -108,26 +108,26 @@ class KIMIface : virtual public DCOPObject
* Get the supplied addressee's current context (home, work, or any).
* @param uid the KABC uid you want the context for.
- * @return A QString describing the context, or null if not supported.
+ * @return A TQString describing the context, or null if not supported.
*/